Command line reference
**********************

.. toctree::
   :maxdepth: 1

   generated/man/datalad-create-sibling-webdav
   generated/man/datalad-credentials
   generated/man/datalad-download
   generated/man/datalad-ls-file-collection
   generated/man/datalad-next-status
   generated/man/datalad-tree
